# pyTheLine

A Python wrapper using the undocumented 'De Lijn' API

Shoutout to the De Mey brothers to start reverse-engineering the API:
https://demey.io/reverse-engineering-belgium-de-lijn/
And creating some very nice documentation:
http://docs.delijn.apiary.io/